Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJeroen Bakker <jeroen@blender.org>2021-03-05 17:46:31 +0300
committerJeroen Bakker <jeroen@blender.org>2021-03-05 18:56:14 +0300
commitfde150fee476e16ee6130618ed1ea2598913f1b6 (patch)
tree059871edeef440940701bcf0011bb7611916fc43 /source/blender/compositor/intern/COM_ExecutionGroup.h
parente1d9b095e4f55022e579d246997b48ec2dd409e0 (diff)
Cleanup: Use std::Vector for chunk execution status.
Diffstat (limited to 'source/blender/compositor/intern/COM_ExecutionGroup.h')
-rw-r--r--source/blender/compositor/intern/COM_ExecutionGroup.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/source/blender/compositor/intern/COM_ExecutionGroup.h b/source/blender/compositor/intern/COM_ExecutionGroup.h
index bfd745d8320..415505616bd 100644
--- a/source/blender/compositor/intern/COM_ExecutionGroup.h
+++ b/source/blender/compositor/intern/COM_ExecutionGroup.h
@@ -23,6 +23,8 @@
#endif
#include "BLI_rect.h"
+#include "BLI_vector.hh"
+
#include "COM_CompositorContext.h"
#include "COM_Device.h"
#include "COM_MemoryProxy.h"
@@ -149,12 +151,12 @@ class ExecutionGroup {
unsigned int m_chunksFinished;
/**
* \brief the chunkExecutionStates holds per chunk the execution state. this state can be
* - eChunkExecutionState::NOT_SCHEDULED: not scheduled
* - eChunkExecutionState::SCHEDULED: scheduled
* - eChunkExecutionState::EXECUTED: executed
*/
- eChunkExecutionState *m_chunkExecutionStates;
+ blender::Vector<eChunkExecutionState> m_chunk_execution_states;
/**
* \brief indicator when this ExecutionGroup has valid Operations in its vector for Execution
@@ -149,12 +151,12 @@ class ExecutionGroup {
unsigned int m_chunksFinished;
/**
- * \brief the chunkExecutionStates holds per chunk the execution state. this state can be
+ * \brief m_chunk_execution_states holds per chunk the execution state. this state can be
* - eChunkExecutionState::NOT_SCHEDULED: not scheduled
* - eChunkExecutionState::SCHEDULED: scheduled